register_handlers

Macro register_handlers 

register_handlers!() { /* proc-macro */ }
Registers a list of command handlers with a target from register_handlers!(<context>, <target>, [<module names>]), instantiating each handler and attaching it to the target’s command tree.