pub trait Context:
Sync
+ Send
+ AnySync {
// Required method
fn term(&self) -> Arc<Terminal> ⓘ;
}Expand description
Shared execution context passed to command handlers, providing access to the underlying terminal and allowing downcasting to a concrete type.
Required Methods
Implementations
Sourceimpl dyn Context
impl dyn Context
pub fn is<_T>(&self) -> bool
pub fn downcast_ref<_T>(&self) -> Result<&_T, TypeMismatch>
pub fn downcast_mut<_T>(&mut self) -> Result<&mut _T, TypeMismatch>
pub fn downcast<_T>( self: Box<Self>, ) -> Result<Box<_T>, DowncastError<Box<Self>>>
pub fn downcast_rc<_T>( self: Rc<Self>, ) -> Result<Rc<_T>, DowncastError<Rc<Self>>>
pub fn downcast_arc<_T>(
self: Arc<Self>,
) -> Result<Arc<_T>, DowncastError<Arc<Self>>>where
_T: AnySync,
Self: DowncastSync<_T>,
Sourceimpl dyn Context + Sync + Send
impl dyn Context + Sync + Send
pub fn is<_T>(&self) -> bool
pub fn downcast_ref<_T>(&self) -> Result<&_T, TypeMismatch>
pub fn downcast_mut<_T>(&mut self) -> Result<&mut _T, TypeMismatch>
pub fn downcast<_T>( self: Box<Self>, ) -> Result<Box<_T>, DowncastError<Box<Self>>>
pub fn downcast_rc<_T>( self: Rc<Self>, ) -> Result<Rc<_T>, DowncastError<Rc<Self>>>
pub fn downcast_arc<_T>(
self: Arc<Self>,
) -> Result<Arc<_T>, DowncastError<Arc<Self>>>where
_T: AnySync,
Self: DowncastSync<_T>,